@@ -1,4 +1,4 @@
 from .account import Account
 from .node import Node
-from .page import Page
+from .page import Page, PagesList
 from .uploaded_file import UploadedFile
